@@ -460,7 +460,7 @@ fill_combo_box(GtkIconTheme* theme, GtkComboBox* combo_box, GList* app_list, gch
         if(g_strrstr(icon_name,"webbrowser")){
             icon_name = g_strdup("webbrowser-app");
         }
-		if (icon_name == NULL)
+        if (icon_name == NULL || g_strcmp0(icon_name, "display-im6.q16") == 0)
 		{
 			/* Default icon */
 			icon_name = g_strdup("binary");
